@@ -37,6 +37,8 @@ factory <- function(tab,
     factory_fun <- factory_DT
   } else if (settings_equal("output_factory", "dataframe")) {
     factory_fun <- factory_dataframe
+  } else if (settings_equal("output_factory", "modelsummary")) {
+    factory_fun <- factory_markdown
   }
 
   # flat header if necessary
@@ -190,4 +192,4 @@ factory <- function(tab,
   } else {
     return(out)
   }
-}
+}
\ No newline at end of file
